import math

primes = {1: False}

def is_prime(n):
    if n in primes:
        return primes[n]

    i = 2
    while i*i <= n:
        if (n % i) == 0:
            primes[n] = False
            return False
        i += 1

    primes[n] = True
    return True

def gen_non_prime(start, end):
    return [n for n in range(start, end+1) if not is_prime(n)]

def gen_prime(end):
    primes = [2]

    def check(n):
        for prime in primes:
            if prime*prime > i:
                break
            if i % prime == 0:
                return False
        return True

    for i in range(3, end):
        if check(i):
            primes.append(i)

    return primes

primes_to_1e5 = gen_prime(10**5)

def deduce_q(qk, k):
    if k == 1:
        return qk

    l, r = 1, 10**((17 + k) // k)

    while l < r:
        c = (l + r) // 2
        ck = c**k

        if ck < qk:
            l = c
        elif ck == qk:
            return c
        else:
            r = c

    return r

def split_to_pqk(n):
    for elm in primes_to_1e5:
        if n % elm == 0:
            k = 1
            n //= elm
            while n % elm == 0:
                k += 1
                n //= elm

            return (elm, deduce_q(n, k), k)

def count_combinations(k):
    dp = {1: {1: 1}} # Stores map of counts of last values of all possible splits

    for i2 in range(0, k+1):
        for i3 in range(0, k+1):
            val = 2**i2 * 3**i3
            res = {val: 1}
            dp[val] = res

            for j2 in range(i2+1):
                for j3 in range(i3+1):
                    sub_val = 2**j2 * 3**j3
                    rel = 2**(i2-j2) * 3**(i3-j3)

                    res[rel] = sum([cnt for val, cnt in dp[sub_val].items() if val <= rel])

            dp[val] = res

    return sum(dp[2**k * 3**k].values()) - 1

def main():
    n = int(input())
    p, q, k = split_to_pqk(n)

    print(count_combinations(k))

if __name__ == '__main__':
    main()
